// DLL class definitions for access to USB HID devices
//
// (C) 2001 Copyright Cleware GmbH
// All rights reserved
//
// History:
// 05.01.2001   ws      Initial coding
// 17.07.2001   ws      cleanup interface
// 10.12.2001   ws      cleanup interface again, basic class to hide implementation details
// 13.12.2001   ws      introduced versionNumber and virtual destructor
// 23.05.2002   ws      added switch access
// 09.01.2002   (rom)   Delphi conversion
// 03.02.2003	ws		added switch version 10
// 04.08.2003	ws		added humidity
// 25.08.2003	ws		second delphi conversion
// 11.06.2004	ws		port USBacess 3.0 to Delphi 7
// 27.07.2004	ws		added 2. Parameter to CalmWatchdog, insert StartDevice
// 20.01.2005	ws		USBaccessVersion 109 / CC 3.1.3

unit USBaccess;

interface

uses
  Windows;

const
   // (rom) aussagekraeftigere Namen fuer die Konstanten/enums waeren gut
   // (rom) ein Prefix wie "act" z. B.
   LEDs           = 0;
   EEwrite        = 1;
   EEread         = 2;
   Reset          = 3;
   KeepCalm       = 4;
   GetInfo        = 5;
   StartMeasuring = 6;
type
  FCWUSBactions = DWORD;

const
  OnlineTime  = 1;
  OnlineCount = 2;
  ManualTime  = 3;
  ManualCount = 4;
type
  FCWUSBInfoType = DWORD;

const
  LED_0 = 0;
  LED_1 = 1;
  LED_2 = 2;
  LED_3 = 3;
type
  FCWLED_IDs = DWORD;

const
  SWITCH_0 = $10;
  SWITCH_1 = $11;
  SWITCH_2 = $12;
  SWITCH_3 = $13;
  SWITCH_4 = $14;
  SWITCH_5 = $15;
  SWITCH_6 = $16;
  SWITCH_7 = $17;
  SWITCH_8 = $18;
  SWITCH_9 = $19;
  SWITCH_10 = $1A;
  SWITCH_11 = $1B;
  SWITCH_12 = $1C;
  SWITCH_13 = $1D;
  SWITCH_14 = $1E;
  SWITCH_15 = $1F;
type
  FCWSWITCH_IDs = DWORD;

const
  ILLEGAL_DEVICE      = 0;
  LED_DEVICE          = $01;
  WATCHDOG_DEVICE     = $05;
  AUTORESET_DEVICE    = $06;
  SWITCH1_DEVICE      = $08;
  SWITCH2_DEVICE      = $09;
  SWITCH3_DEVICE      = $0A;
  SWITCH4_DEVICE      = $0B;
  TEMPERATURE_DEVICE  = $10;
  TEMPERATURE2_DEVICE = $11;
  TEMPERATURE5_DEVICE = $15;
  HUMIDITY1_DEVICE    = $20;
  CONTACT00_DEVICE    = $30;
  CONTACT01_DEVICE    = $31;
  CONTACT02_DEVICE    = $32;
  CONTACT03_DEVICE = $33;
  CONTACT04_DEVICE = $34;
  CONTACT05_DEVICE = $35;
  CONTACT06_DEVICE = $36;
  CONTACT07_DEVICE = $37;
  CONTACT08_DEVICE = $38;
  CONTACT09_DEVICE = $39;
  CONTACT10_DEVICE = $3A;
  CONTACT11_DEVICE = $3B;
  CONTACT12_DEVICE = $3C;
  CONTACT13_DEVICE = $3D;
  CONTACT14_DEVICE = $3E;
  CONTACT15_DEVICE = $3F;
type
  FCWUSBtype_enum = DWORD;

type
  // the C++ class object pointer is simply represented by a untyped pointer
  CUSBaccess = Pointer;

function FCWInitObject: CUSBaccess; stdcall;
procedure FCWUnInitObject(Obj: CUSBaccess); stdcall;
function FCWOpenCleware(Obj: CUSBaccess): Integer; stdcall;   // returns number of found Cleware devices
function FCWCloseCleware(Obj: CUSBaccess): Integer; stdcall;  // close all Cleware devices
function FCWGetHandle(Obj: CUSBaccess; deviceNo: Integer): THandle; stdcall;
function FCWRecover(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
// (rom) buffer ist als PChar (char *) deklariert, da das in Delphi leichter handhabbar ist
function FCWGetValue(Obj: CUSBaccess; deviceNo: Integer; Buf: PChar; bufsize: Integer): Integer; stdcall;
function FCWSetValue(Obj: CUSBaccess; deviceNo: Integer; Buf: PChar; bufsize: Integer): Integer; stdcall;
function FCWSetLED(Obj: CUSBaccess; deviceNo: Integer; Led: FCWLED_IDs; value: Integer): Integer; stdcall;    // value: 0=off 7=medium 15=highlight
// (rom) On ist ein Schluesselwort in Delphi deshalb die Umbenennung
// (rom) hier ist auch eine Inkonsistenz im C header mit den enums
// (rom) es werden die enums aus der Klasse verwendet
// (rom) am besten die enums ganz herausziehen und FCW Namen verwenden
function FCWSetSwitch(Obj: CUSBaccess; deviceNo: Integer; Switch: FCWSWITCH_IDs; On_: Integer): Integer; stdcall; // On: 0=off, 1=on
function FCWGetSwitch(Obj: CUSBaccess; deviceNo: Integer; Switch: FCWSWITCH_IDs): Integer; stdcall;  // On: 0=off, 1=on, -1=error
function FCWGetSeqSwitch(Obj: CUSBaccess; deviceNo: Integer; Switch: FCWSWITCH_IDs; SeqNum: Integer): Integer; stdcall;  // On: 0=off, 1=on, -1=error
function FCWGetSwitchConfig(Obj: CUSBaccess; deviceNo: Integer; var switchCount: Integer; var buttonAvailable: Integer): Integer; stdcall;
function FCWSetTempOffset(Obj: CUSBaccess; deviceNo: Integer; Sollwert, Istwert: Double): Integer; stdcall;
function FCWGetTemperature(Obj: CUSBaccess; deviceNo: Integer; var Temperature: Double; var timeID: Integer): Integer; stdcall;
function FCWGetHumidity(Obj: CUSBaccess; deviceNo: Integer; var Humidity: Double; var timeID: Integer): Integer; stdcall;
function FCWResetDevice(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWStartDevice(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWCalmWatchdog(Obj: CUSBaccess; deviceNo: Integer; minutes1: Integer; minutes2: Integer): Integer; stdcall;
function FCWGetVersion(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWGetUSBType(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWGetSerialNumber(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWGetDLLVersion: Integer; stdcall;
function FCWGetManualOnCount(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWGetManualOnTime(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWGetOnlineOnCount(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWGetOnlineOnTime(Obj: CUSBaccess; deviceNo: Integer): Integer; stdcall;
function FCWGetMultiSwitch(Obj: CUSBaccess; deviceNo: Integer; var mask: Integer; var value: Integer; seqNumber: Integer): Integer; stdcall;
function FCWSetMultiSwitch(Obj: CUSBaccess; deviceNo: Integer; value: Integer): Integer; stdcall;
function FCWSetMultiConfig(Obj: CUSBaccess; deviceNo: Integer; directions: Integer): Integer; stdcall;
function FCWGetCounter(Obj: CUSBaccess; deviceNo: Integer; counter: Integer): Integer; stdcall;
function FCWSyncDevice(Obj: CUSBaccess; deviceNo: Integer; mask: Integer): Integer; stdcall;
procedure FCWDebugWrite(Obj: CUSBaccess; s: PChar); stdcall;
implementation

const
  USBaccessLib = 'USBaccess.dll';

// (rom) irgendwie kann man dem C++ Compiler sagen das man ohne _ und @
// (rom) exportieren will. Ich weiss aber nicht mehr wie das geht.
// (rom) Delphi ist das egal, aber es ist hat schoener.
function FCWCalmWatchdog; external USBaccessLib name '_FCWCalmWatchdog@16';
function FCWCloseCleware; external USBaccessLib name '_FCWCloseCleware@4';
function FCWRecover; external USBaccessLib name '_FCWRecover@8';
function FCWGetDLLVersion; external USBaccessLib name '_FCWGetDLLVersion@0';
function FCWGetHandle; external USBaccessLib name '_FCWGetHandle@8';
function FCWGetSerialNumber; external USBaccessLib name '_FCWGetSerialNumber@8';
function FCWGetSwitch; external USBaccessLib name '_FCWGetSwitch@12';
function FCWGetSeqSwitch; external USBaccessLib name '_FCWGetSwitch@16';
function FCWGetSwitchConfig; external USBaccessLib name '_FFCWGetSwitchConfig@16';
function FCWGetTemperature; external USBaccessLib name '_FCWGetTemperature@16';
function FCWGetHumidity; external USBaccessLib name '_FCWGetHumidity@16';
function FCWGetUSBType; external USBaccessLib name '_FCWGetUSBType@8';
function FCWGetValue; external USBaccessLib name '_FCWGetValue@16';
function FCWGetVersion; external USBaccessLib name '_FCWGetVersion@8';
function FCWInitObject; external USBaccessLib name '_FCWInitObject@0';
function FCWOpenCleware; external USBaccessLib name '_FCWOpenCleware@4';
function FCWResetDevice; external USBaccessLib name '_FCWResetDevice@8';
function FCWStartDevice; external USBaccessLib name '_FCWStartDevice@8';
function FCWSetLED; external USBaccessLib name '_FCWSetLED@16';
function FCWSetSwitch; external USBaccessLib name '_FCWSetSwitch@16';
function FCWSetTempOffset; external USBaccessLib name '_FCWSetTempOffset@24';
function FCWSetValue; external USBaccessLib name '_FCWSetValue@16';
function FCWGetManualOnCount; external USBaccessLib name '_FCWGetManualOnCount@8';
function FCWGetManualOnTime; external USBaccessLib name '_FCWGetManualOnTime@8';
function FCWGetOnlineOnCount; external USBaccessLib name '_FCWGetOnlineOnCount@8';
function FCWGetOnlineOnTime; external USBaccessLib name '_FCWGetOnlineOnTime@8';
function FCWGetMultiSwitch; external USBaccessLib name '_FCWGetMultiSwitch@20' ;
function FCWSetMultiSwitch; external USBaccessLib name '_FCWSetMultiSwitch@12' ;
function FCWSetMultiConfig; external USBaccessLib name '_FCWSetMultiConfig@12' ;
function FCWGetCounter; external USBaccessLib name '_FCWGetCounter@12' ;
function FCWSyncDevice; external USBaccessLib name '_FCWSyncDevice@12' ;
procedure FCWDebugWrite; external USBaccessLib name '_FCWDebugWrite@8' ;
procedure FCWUnInitObject; external USBaccessLib name '_FCWUnInitObject@4';

end.
