unit USBaccessTestMain;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls,
  DBT, USBaccess;

type
  TUSBaccessMainForm = class(TForm)
    DeviceList: TListBox;
    Button1: TButton;
    Button2: TButton;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  public
    USBaccessHandle: CUSBaccess;
    procedure EnumerateDevices;
    procedure WMDeviceChange(var Msg: TMessage); message WM_DEVICECHANGE;
  end;

var
  USBaccessMainForm: TUSBaccessMainForm;
  DevCount: Integer;


implementation

{$R *.dfm}

procedure TUSBaccessMainForm.FormCreate(Sender: TObject);
begin
  USBaccessHandle := FCWInitObject;
  DevCount := FCWOpenCleware(USBaccessHandle) ;
  EnumerateDevices;
end;

procedure TUSBaccessMainForm.FormDestroy(Sender: TObject);
begin
  FCWCloseCleware(USBaccessHandle);
  FCWUnInitObject(USBaccessHandle);
end;

procedure TUSBaccessMainForm.EnumerateDevices;
var
  I: Integer;
  DevKind: FCWUSBtype_enum;
  Measure: Double;
  MeasureTime: Integer ;
  fstat: Integer ;
  retry: Integer ;
begin
  Measure := -200. ;
  MeasureTime := 0 ;
  DeviceList.Clear;
  if (DevCount <= 0) then
    DeviceList.Items.Add('no device found');
  for I := 0 to DevCount-1 do
  begin
    DevKind := FCWGetUSBType(USBaccessHandle, I);
    case DevKind of
      ILLEGAL_DEVICE:
        DeviceList.Items.Add(Format('%d: ILLEGAL', [I]));
      LED_DEVICE:
        DeviceList.Items.Add(Format('%d: LED', [I]));
      WATCHDOG_DEVICE:
        DeviceList.Items.Add(Format('%d: WATCHDOG', [I]));
      AUTORESET_DEVICE:
        DeviceList.Items.Add(Format('%d: AUTORESET', [I]));
      SWITCH1_DEVICE:
        DeviceList.Items.Add(Format('%d: SWITCH1', [I]));
      TEMPERATURE_DEVICE:
        DeviceList.Items.Add(Format('%d: TEMPERATURE', [I]));
      TEMPERATURE2_DEVICE:
        begin
          retry := 0 ;
          repeat
            if (retry <> 0) then Sleep(100) ;
            retry := retry + 1 ;
            fstat := FCWGetTemperature(USBaccessHandle, I, Measure, MeasureTime) ;
          until (fstat > 0) or (retry < 5) ;
          if (Measure < -100) then
            FCWResetDevice(USBaccessHandle, I)
          else
            DeviceList.Items.Add(Format('%d=TEMPERATURE2: Value=%f', [I, Measure]));
        end
    end;
  end ;
end;

procedure TUSBaccessMainForm.WMDeviceChange(var Msg: TMessage);
begin
  if Msg.WParam = DBT_DEVNODES_CHANGED then
//    EnumerateDevices;
end;

procedure TUSBaccessMainForm.Button1Click(Sender: TObject);
begin
    EnumerateDevices;
end;

procedure TUSBaccessMainForm.Button2Click(Sender: TObject);
var
  I: Integer;
  DevKind: FCWUSBtype_enum;
  fstat: Integer ;
  retry: Integer ;
begin
  for I := 0 to DevCount-1 do
  begin
    DevKind := FCWGetUSBType(USBaccessHandle, I);
    if (DevKind = SWITCH1_DEVICE) then
    begin
       retry := 0 ;
       repeat
         if (retry <> 0) then Sleep(100) ;
         retry := retry + 1 ;
         fstat := FCWGetSwitch(USBaccessHandle, I, SWITCH_0) ;
       until (fstat >= 0) or (retry < 5) ;
       if (fstat >= 0) then
          if (fstat = 0) then
            FCWSetSwitch(USBaccessHandle, I, SWITCH_0, 1)
          else
            FCWSetSwitch(USBaccessHandle, I, SWITCH_0, 0) ;
    end;
  end ;

end;

end.
